@@ -170,6 +170,31 @@ reload_net_wm_pid (MetaWindow    *window,
     }
 }
 
+static void
+init_net_wm_user_time (MetaDisplay   *display,
+                       Atom           property,
+                       MetaPropValue *value)
+{
+  value->type = META_PROP_VALUE_CARDINAL;
+  value->atom = display->atom_net_wm_user_time;
+}
+
+static void
+reload_net_wm_user_time (MetaWindow    *window,
+                         MetaPropValue *value)
+{
+  if (value->type != META_PROP_VALUE_INVALID)
+    {
+      gulong cardinal = value->v.cardinal;
+
+      window->net_wm_user_time_set = TRUE;
+      window->net_wm_user_time = cardinal;
+      meta_topic (META_DEBUG_STARTUP,
+                  "Window %s has _NET_WM_USER_TIME of %lu\n",
+                  window->desc, window->net_wm_user_time);
+    }
+}
+
 static void
 set_window_title (MetaWindow *window,
                   const char *title)
@@ -385,7 +410,7 @@ init_update_counter (MetaDisplay   *display,
                      MetaPropValue *value)
 {
   value->type = META_PROP_VALUE_SYNC_COUNTER;
-  value->atom = display->atom_metacity_update_counter;
+  value->atom = display->atom_net_wm_sync_request_counter;
 }
 
 static void
@@ -397,9 +422,9 @@ reload_update_counter (MetaWindow    *window,
 #ifdef HAVE_XSYNC
       XSyncCounter counter = value->v.xcounter;
 
-      window->update_counter = counter;
-      meta_verbose ("Window has _METACITY_UPDATE_COUNTER 0x%lx\n",
-                    window->update_counter);
+      window->sync_request_counter = counter;
+      meta_verbose ("Window has _NET_WM_SYNC_REQUEST_COUNTER 0x%lx\n",
+                    window->sync_request_counter);
 #endif
     }
 }
@@ -814,7 +839,7 @@ reload_wm_hints (MetaWindow    *window,
 
 
 
-#define N_HOOKS 23
+#define N_HOOKS 24
 
 void
 meta_display_init_window_prop_hooks (MetaDisplay *display)
@@ -844,6 +869,11 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
   hooks[i].reload_func = reload_net_wm_pid;
   ++i;
 
+  hooks[i].property = display->atom_net_wm_user_time;
+  hooks[i].init_func = init_net_wm_user_time;
+  hooks[i].reload_func = reload_net_wm_user_time;
+  ++i;
+
   hooks[i].property = display->atom_net_wm_name;
   hooks[i].init_func = init_net_wm_name;
   hooks[i].reload_func = reload_net_wm_name;
@@ -924,7 +954,7 @@ meta_display_init_window_prop_hooks (MetaDisplay *display)
   hooks[i].reload_func = reload_net_startup_id;
   ++i;
 
-  hooks[i].property = display->atom_metacity_update_counter;
+  hooks[i].property = display->atom_net_wm_sync_request_counter;
   hooks[i].init_func = init_update_counter;
   hooks[i].reload_func = reload_update_counter;
   ++i;
